# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'OrganizationConfigurationAutoEnableArgs',
]

@pulumi.input_type
class OrganizationConfigurationAutoEnableArgs:
    def __init__(__self__, *,
                 ec2: pulumi.Input[bool],
                 ecr: pulumi.Input[bool]):
        """
        :param pulumi.Input[bool] ec2: Whether Amazon EC2 scans are automatically enabled for new members of your Amazon Inspector organization.
        :param pulumi.Input[bool] ecr: Whether Amazon ECR scans are automatically enabled for new members of your Amazon Inspector organization.
        """
        pulumi.set(__self__, "ec2", ec2)
        pulumi.set(__self__, "ecr", ecr)

    @property
    @pulumi.getter
    def ec2(self) -> pulumi.Input[bool]:
        """
        Whether Amazon EC2 scans are automatically enabled for new members of your Amazon Inspector organization.
        """
        return pulumi.get(self, "ec2")

    @ec2.setter
    def ec2(self, value: pulumi.Input[bool]):
        pulumi.set(self, "ec2", value)

    @property
    @pulumi.getter
    def ecr(self) -> pulumi.Input[bool]:
        """
        Whether Amazon ECR scans are automatically enabled for new members of your Amazon Inspector organization.
        """
        return pulumi.get(self, "ecr")

    @ecr.setter
    def ecr(self, value: pulumi.Input[bool]):
        pulumi.set(self, "ecr", value)


